select *
from meter_data FINAL;

select meter_attr_id,timestamp
     ,argMinMerge(first) as first
     ,argMaxMerge(last) as last
     ,maxMerge(max) as max
     ,minMerge(min) as min
     ,avgMerge(avg) as avg
     ,sumMerge(sum) as sum
     ,countMerge(count) as count
from meter_attr_hour_statistics
GROUP BY meter_attr_id,timestamp
ORDER BY timestamp DESC;


select meter_attr_id,toStartOfDay(base.timestamp) as time
,argMin(first, base.timestamp) as first
,argMax(last, base.timestamp) as last
,max(max) as max
,min(min) as min
,sum/count as avg
,sum(sum) as sum
,sum(count) as count
from(
    select meter_attr_id,timestamp
         ,argMinMerge(first) as first
         ,argMaxMerge(last) as last
         ,maxMerge(max) as max
         ,minMerge(min) as min
         ,avgMerge(avg) as avg
         ,sumMerge(sum) as sum
         ,countMerge(count) as count
    from meter_attr_hour_statistics
    GROUP BY meter_attr_id,timestamp
    ORDER BY timestamp DESC
) as base
group by meter_attr_id,time;


-- 插入数据
insert into meter_data values(1,'1.1',1,now(),1);

insert into meter_data values(9,'101',1,'2024-08-07 15:40:30.000000',1);



-- 物化视图
drop VIEW if exists meter_attr_hour_statistics_mv;
drop table if exists meter_attr_hour_statistics;

create table meter_attr_hour_statistics
(
  "meter_attr_id" Int64,
  "timestamp" DateTime64(0),
  "first" AggregateFunction(argMin, String,DateTime64(6)),
  "last" AggregateFunction(argMax, String,DateTime64(6)),
  "min" AggregateFunction(min, Decimal64(6)),
  "max" AggregateFunction(max, Decimal64(6)),
  "sum" AggregateFunction(sum, Decimal64(6)),
  "count" AggregateFunction(count, UInt32),
  "avg" AggregateFunction(avg, Decimal64(6))
)
engine = AggregatingMergeTree
        PARTITION BY toDate(timestamp)
        ORDER BY (timestamp, meter_attr_id);


CREATE MATERIALIZED VIEW meter_attr_hour_statistics_mv
-- REFRESH EVERY 1 MINUTE
    To meter_attr_hour_statistics As
 select meter_attr_id
        , toStartOfHour(base.timestamp) AS timestamp
        , argMinState(base.value, base.timestamp) as first
        , argMaxState(base.value, base.timestamp) as last
        , minState(toDecimal64(base.value, 6)) as min
        , maxState(toDecimal64(base.value, 6)) as max
        , sumState(toDecimal64(base.value, 6)) as sum
        , countState(1) as count
        , avgState(toDecimal64(base.value, 6)) as avg
        from meter_data as base
        GROUP BY meter_attr_id, timestamp
        ORDER BY timestamp;


-- 表存储容量统计
 select
    database,
    table,
    formatReadableSize(size) as size,
    formatReadableSize(bytes_on_disk) as bytes_on_disk,
    formatReadableSize(data_uncompressed_bytes) as data_uncompressed_bytes,
    formatReadableSize(data_compressed_bytes) as data_compressed_bytes,
    compress_rate,
    rows,
    days,
    formatReadableSize(avgDaySize) as avgDaySize
from
(
    select
        database,
        table,
        sum(bytes) as size,
        sum(rows) as rows,
        min(min_date) as min_date,
        max(max_date) as max_date,
        sum(bytes_on_disk) as bytes_on_disk,
        sum(data_uncompressed_bytes) as data_uncompressed_bytes,
        sum(data_compressed_bytes) as data_compressed_bytes,
        (data_compressed_bytes / data_uncompressed_bytes) * 100 as compress_rate,
        max_date - min_date as days,
        size / (max_date - min_date) as avgDaySize
    from system.parts
    where active
--      and database = 'system'
     and database = 'default'
--      and table = 'meter_data'
    group by
        database,
        table
    order by size desc
);